==> rc-time-picker-3.4.0.jar: META-INF/resources/webjars/rc-time-picker/3.4.0/HISTORY.md <==
# History

3.4.0 / 2019-08-13
---------------------------

- Add `inputIcon`

3.3.0 / 2019-02-8
---------------------------

- Add `inputReadOnly`

3.2.0 / 2017-11-15
---------------------------

- Add  `blur()` and `autoFocus`.


3.1.0 / 2017-11-02
---------------------------

- Upgrade to `rc-trigger@2.x`.


3.0.0 / 2017-10-22
---------------------------

- Support React 16.
- Add `onKeydown`.
- Add `focusOnOpen`.
- Add `hourStep` `minuteStep` `secondStep`.
- Fix disabled style.
- Use `this.xxx` to replace `this.refs.xxx`.

2.4.0 / 2017-05-02
---------------------------

Add `popupClassName` prop.

2.3.0 / 2017-03-08
---------------------------

Add `use12Hours` prop.

2.2.0 / 2016-11-11
---------------------------

Add `showMinute` prop.

2.1.0 / 2016-10-25
---------------------------

Add `addon` prop.

2.0.0 / 2016-08-04
---------------------------

goodbye gregorian-calendar, hello moment

1.1.0 / 2016-01-14
---------------------------

remove gregorianCalendarLocale prop, move to locale.calendar

1.0.0 / 2015-12-21
-------------------------

release!

1.0.0-alpha9 / 2015-12-16
------------------

`fixed` update bugs when value empty.

1.0.0-alpha7 / 2015-12-12
------------------

`new` add options `disabledHours`, `disabledMinutes`, `disabledSeconds` and `hideDisabledOptions`.
`remove` remove options `hourOptions`, `minuteOptions` and `secondOptions`.

1.0.0-alpha2 / 2015-12-03
------------------

`fixed` IE8 compatible.
`new` add test users.

0.7.1 / 2015-11-20
------------------

`fixed` change value to null when clear input content to remove the react warning.

0.7.0 / 2015-11-20
------------------

`update` change the className of panel and its container.

0.5.6 / 2015-11-19
------------------

`fixed` use another method to change time and fix the bug about value.getTime().

0.5.4 / 2015-11-19
------------------

`update` change value prop to defaultValue.

0.5.2 / 2015-11-19
------------------

`update` renew placements config.

0.5.1 / 2015-11-19
------------------

`update` change the className of select panel container.

0.5.0 / 2015-11-19
------------------

`update` clear input content and close select panel when click [x] on select panel.

`new` can custom input className now.


0.4.0 / 2015-11-18
------------------

`update` clear input content when click [x] on select panel.

0.3.3 / 2015-11-17
------------------

`fixed` fix some bugs.

0.3.0 / 2015-11-17
------------------

`update` remove TimePanel and merge it to TimePicker.

0.2.0 / 2015-11-16
------------------

`update` rename the component, update document.

0.1.0 / 2015-11-12
------------------

`new` [#305](https://github.com/ant-design/ant-design/issues/305#issuecomment-147027817) release 0.1.0 ([@wuzhao](https://github.com/wuzhao)\)

==> rc-time-picker-3.7.1.jar: META-INF/resources/webjars/rc-time-picker/3.7.1/HISTORY.md <==
# History

3.7.0 / 2019-06-13
---------------------------

- Improve accessibility. #153

3.6.0
---------------------------

- Refacotr dom structure.

3.5.0 / 2018-12-23
---------------------------

- Add `popupStyle`
- Add `onAmPmChange`
- Add Typescript definition

3.4.0 / 2018-08-13
---------------------------

- Add `inputIcon`

3.3.0 / 2018-02-08
---------------------------

- Add `inputReadOnly`

3.2.0 / 2017-11-15
---------------------------

- Add  `blur()` and `autoFocus`.


3.1.0 / 2017-11-02
---------------------------

- Upgrade to `rc-trigger@2.x`.


3.0.0 / 2017-10-22
---------------------------

- Support React 16.
- Add `onKeydown`.
- Add `focusOnOpen`.
- Add `hourStep` `minuteStep` `secondStep`.
- Fix disabled style.
- Use `this.xxx` to replace `this.refs.xxx`.

2.4.0 / 2017-05-02
---------------------------

Add `popupClassName` prop.

2.3.0 / 2017-03-08
---------------------------

Add `use12Hours` prop.

2.2.0 / 2016-11-11
---------------------------

Add `showMinute` prop.

2.1.0 / 2016-10-25
---------------------------

Add `addon` prop.

2.0.0 / 2016-08-04
---------------------------

goodbye gregorian-calendar, hello moment

1.1.0 / 2016-01-14
---------------------------

remove gregorianCalendarLocale prop, move to locale.calendar

1.0.0 / 2015-12-21
-------------------------

release!

1.0.0-alpha9 / 2015-12-16
------------------

`fixed` update bugs when value empty.

1.0.0-alpha7 / 2015-12-12
------------------

`new` add options `disabledHours`, `disabledMinutes`, `disabledSeconds` and `hideDisabledOptions`.
`remove` remove options `hourOptions`, `minuteOptions` and `secondOptions`.

1.0.0-alpha2 / 2015-12-03
------------------

`fixed` IE8 compatible.
`new` add test users.

0.7.1 / 2015-11-20
------------------

`fixed` change value to null when clear input content to remove the react warning.

0.7.0 / 2015-11-20
------------------

`update` change the className of panel and its container.

0.5.6 / 2015-11-19
------------------

`fixed` use another method to change time and fix the bug about value.getTime().

0.5.4 / 2015-11-19
------------------

`update` change value prop to defaultValue.

0.5.2 / 2015-11-19
------------------

`update` renew placements config.

0.5.1 / 2015-11-19
------------------

`update` change the className of select panel container.

0.5.0 / 2015-11-19
------------------

`update` clear input content and close select panel when click [x] on select panel.

`new` can custom input className now.


0.4.0 / 2015-11-18
------------------

`update` clear input content when click [x] on select panel.

0.3.3 / 2015-11-17
------------------

`fixed` fix some bugs.

0.3.0 / 2015-11-17
------------------

`update` remove TimePanel and merge it to TimePicker.

0.2.0 / 2015-11-16
------------------

`update` rename the component, update document.

0.1.0 / 2015-11-12
------------------

`new` [#305](https://github.com/ant-design/ant-design/issues/305#issuecomment-147027817) release 0.1.0 ([@wuzhao](https://github.com/wuzhao)\)
